@@ -381,41 +381,42 @@ def split_wet_file(wet_file_path, counter_inc_fn=None):
       return True
     return False
 
-  with tf.io.gfile.GFile(wet_file_path,
-                         "rb") as f, gzip.GzipFile(fileobj=f) as g:
-    page = PageFeatures()
-    for i, line in enumerate(io.TextIOWrapper(g, encoding="utf-8")):  # pytype: disable=wrong-arg-types
-      line = line.strip()
-      if not line:
-        continue
-      if line == _PAGE_DELIMITER:
-        if i > 0 and _validate_features(page):
-          yield page
-        page = PageFeatures()
+  try:
+    with tf.io.gfile.GFile(wet_file_path, "rb") as f, gzip.GzipFile(fileobj=f) as g:
+      page = PageFeatures()
+      for i, line in enumerate(io.TextIOWrapper(g, encoding="utf-8")):  # pytype: disable=wrong-arg-types
+        line = line.strip()
+        if not line:
+          continue
+        if line == _PAGE_DELIMITER:
+          if i > 0 and _validate_features(page):
+            yield page
+          page = PageFeatures()
 
-      if line.startswith(_URL_KEY):
-        page.url = line[len(_URL_KEY):].strip()
-        page.normalized_url = normalize_url(line[len(_URL_KEY):].strip())
+        if line.startswith(_URL_KEY):
+          page.url = line[len(_URL_KEY):].strip()
+          page.normalized_url = normalize_url(line[len(_URL_KEY):].strip())
 
-      if line.startswith(_URL_DATE):
-        page.timestamp = line[len(_URL_DATE):].strip()
+        if line.startswith(_URL_DATE):
+          page.timestamp = line[len(_URL_DATE):].strip()
 
-      if line.startswith(_CONTENT_TYPE):
-        page.content_type = line[len(_CONTENT_TYPE):].strip()
+        if line.startswith(_CONTENT_TYPE):
+          page.content_type = line[len(_CONTENT_TYPE):].strip()
 
-      if line.startswith(_CONTENT_LEN):
-        page.content_length = line[len(_CONTENT_LEN):].strip()
+        if line.startswith(_CONTENT_LEN):
+          page.content_length = line[len(_CONTENT_LEN):].strip()
 
-      if line.startswith(_METADATA_PREFIXES):
-        continue
+        if line.startswith(_METADATA_PREFIXES):
+          continue
 
-      if page.text:
-        page.text += "\n"
-      page.text += line
-
-    if _validate_features(page):
-      yield page
+        if page.text:
+          page.text += "\n"
+        page.text += line
 
+      if _validate_features(page):
+        yield page
+  except Exception as ex:
+    logging.error(f"Corrupt wet file: {wet_file_path} | {ex}")
 
 def select_newest_page(pages):
   """Deterministically return as random page."""
